@@ -1,4 +1,5 @@
 """Combine code coverage files."""
+
 from __future__ import annotations
 
 import collections.abc as c
@@ -34,6 +35,7 @@ from ...executor import (
 
 from ...data import (
     data_context,
+    PayloadConfig,
 )
 
 from ...host_configs import (
@@ -82,9 +84,10 @@ def combine_coverage_files(args: CoverageCombineConfig, host_state: HostState) -
 
             pairs = [(path, os.path.relpath(path, data_context().content.root)) for path in exported_paths]
 
-            def coverage_callback(files: list[tuple[str, str]]) -> None:
+            def coverage_callback(payload_config: PayloadConfig) -> None:
                 """Add the coverage files to the payload file list."""
                 display.info('Including %d exported coverage file(s) in payload.' % len(pairs), verbosity=1)
+                files = payload_config.files
                 files.extend(pairs)
 
             data_context().register_payload_callback(coverage_callback)
@@ -101,11 +104,13 @@ def combine_coverage_files(args: CoverageCombineConfig, host_state: HostState) -
 
 class ExportedCoverageDataNotFound(ApplicationError):
     """Exception when no combined coverage data is present yet is required."""
+
     def __init__(self) -> None:
         super().__init__(
             'Coverage data must be exported before processing with the `--docker` or `--remote` option.\n'
             'Export coverage with `ansible-test coverage combine` using the `--export` option.\n'
-            'The exported files must be in the directory: %s/' % ResultType.COVERAGE.relative_path)
+            'The exported files must be in the directory: %s/' % ResultType.COVERAGE.relative_path
+        )
 
 
 def _command_coverage_combine_python(args: CoverageCombineConfig, host_state: HostState) -> list[str]:
@@ -117,7 +122,7 @@ def _command_coverage_combine_python(args: CoverageCombineConfig, host_state: Ho
     coverage_files = get_python_coverage_files()
 
     def _default_stub_value(source_paths: list[str]) -> dict[str, set[tuple[int, int]]]:
-        return {path: set() for path in source_paths}
+        return {path: {(0, 0)} for path in source_paths}
 
     counter = 0
     sources = _get_coverage_targets(args, walk_compile_targets)
@@ -351,6 +356,7 @@ def get_coverage_group(args: CoverageCombineConfig, coverage_file: str) -> t.Opt
 
 class CoverageCombineConfig(CoverageConfig):
     """Configuration for the coverage combine command."""
+
     def __init__(self, args: t.Any) -> None:
         super().__init__(args)
 
@@ -359,4 +365,4 @@ class CoverageCombineConfig(CoverageConfig):
         self.stub: bool = args.stub
 
         # only available to coverage combine
-        self.export: str = args.export if 'export' in args else False
+        self.export: str | None = args.export if 'export' in args else None
